==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/CommodityChannelIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CommodityChannelIndexIndicatorStrategy } from "./CommodityChannelIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let CommodityChannelIndexIndicator = /*@__PURE__*/ (() => {
    class CommodityChannelIndexIndicator extends StrategyBasedIndicator {
        get_yy() {
            return new CommodityChannelIndexIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return CommodityChannelIndexIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(CommodityChannelIndexIndicator.zk));
        }
        set zj(a) {
            this.h(CommodityChannelIndexIndicator.zk, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
    }
    CommodityChannelIndexIndicator.$t = /*@__PURE__*/ markType(CommodityChannelIndexIndicator, 'CommodityChannelIndexIndicator', StrategyBasedIndicator.$);
    CommodityChannelIndexIndicator.zk = /*@__PURE__*/ StrategyBasedIndicator.zg(20, CommodityChannelIndexIndicator.$);
    return CommodityChannelIndexIndicator;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/CommodityChannelIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { CommodityChannelIndexIndicatorStrategy } from "./CommodityChannelIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let CommodityChannelIndexIndicator = /*@__PURE__*/ (() => {
    class CommodityChannelIndexIndicator extends StrategyBasedIndicator {
        bj() {
            return new CommodityChannelIndexIndicator();
        }
        get_abq() {
            return new CommodityChannelIndexIndicatorStrategy();
        }
        get abq() {
            return this.get_abq();
        }
        get_ab3() {
            return CommodityChannelIndexIndicator.$;
        }
        get ab3() {
            return this.get_ab3();
        }
        get acb() {
            return typeGetValue(this.c(CommodityChannelIndexIndicator.acc));
        }
        set acb(a) {
            this.h(CommodityChannelIndexIndicator.acc, a);
        }
        abw() {
            return this.acb;
        }
        ab5(a) {
            this.acb = a;
        }
    }
    CommodityChannelIndexIndicator.$t = /*@__PURE__*/ markType(CommodityChannelIndexIndicator, 'CommodityChannelIndexIndicator', StrategyBasedIndicator.$);
    CommodityChannelIndexIndicator.acc = /*@__PURE__*/ StrategyBasedIndicator.ab8(20, CommodityChannelIndexIndicator.$);
    return CommodityChannelIndexIndicator;
})();
